@@ -21,16 +21,16 @@ OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
 module.exports = function(jasmineRequire) {
-  var jasmine = jasmineRequire.core(jasmineRequire);
+  const jasmine = jasmineRequire.core(jasmineRequire);
 
-  var env = jasmine.getEnv({ suppressLoadErrors: true });
+  const env = jasmine.getEnv({ suppressLoadErrors: true });
 
-  var jasmineInterface = jasmineRequire.interface(jasmine, env);
+  const jasmineInterface = jasmineRequire.interface(jasmine, env);
 
   extend(global, jasmineInterface);
 
   function extend(destination, source) {
-    for (var property in source) destination[property] = source[property];
+    for (const property in source) destination[property] = source[property];
     return destination;
   }
 
