@@ -1,12 +1,12 @@
 describe('Spec', function() {
   it('#isPendingSpecException returns true for a pending spec exception', function() {
-    var e = new Error(jasmineUnderTest.Spec.pendingSpecExceptionMessage);
+    const e = new Error(jasmineUnderTest.Spec.pendingSpecExceptionMessage);
 
     expect(jasmineUnderTest.Spec.isPendingSpecException(e)).toBe(true);
   });
 
   it('#isPendingSpecException returns true for a pending spec exception (even when FF bug is present)', function() {
-    var fakeError = {
+    const fakeError = {
       toString: function() {
         return 'Error: ' + jasmineUnderTest.Spec.pendingSpecExceptionMessage;
       }
@@ -24,7 +24,7 @@ describe('Spec', function() {
   });
 
   it('#isPendingSpecException returns false for not a pending spec exception', function() {
-    var e = new Error('foo');
+    const e = new Error('foo');
 
     expect(jasmineUnderTest.Spec.isPendingSpecException(e)).toBe(false);
   });
@@ -34,31 +34,29 @@ describe('Spec', function() {
   });
 
   it('delegates execution to a QueueRunner', function() {
-    var fakeQueueRunner = jasmine.createSpy('fakeQueueRunner'),
+    const fakeQueueRunner = jasmine.createSpy('fakeQueueRunner'),
       spec = new jasmineUnderTest.Spec({
         description: 'my test',
         id: 'some-id',
-        queueableFn: { fn: function() {} },
-        queueRunnerFactory: fakeQueueRunner
+        queueableFn: { fn: function() {} }
       });
 
-    spec.execute();
+    spec.execute(fakeQueueRunner);
 
     expect(fakeQueueRunner).toHaveBeenCalled();
   });
 
   it('should call the start callback on execution', function() {
-    var fakeQueueRunner = jasmine.createSpy('fakeQueueRunner'),
+    const fakeQueueRunner = jasmine.createSpy('fakeQueueRunner'),
       startCallback = jasmine.createSpy('startCallback'),
       spec = new jasmineUnderTest.Spec({
         id: 123,
         description: 'foo bar',
         queueableFn: { fn: function() {} },
-        onStart: startCallback,
-        queueRunnerFactory: fakeQueueRunner
+        onStart: startCallback
       });
 
-    spec.execute();
+    spec.execute(fakeQueueRunner);
 
     fakeQueueRunner.calls.mostRecent().args[0].queueableFns[0].fn();
     expect(startCallback).toHaveBeenCalled();
@@ -66,34 +64,33 @@ describe('Spec', function() {
   });
 
   it('should call the start callback on execution but before any befores are called', function() {
-    var fakeQueueRunner = jasmine.createSpy('fakeQueueRunner'),
-      beforesWereCalled = false,
-      startCallback = jasmine
-        .createSpy('start-callback')
-        .and.callFake(function() {
-          expect(beforesWereCalled).toBe(false);
-        }),
-      spec = new jasmineUnderTest.Spec({
-        queueableFn: { fn: function() {} },
-        beforeFns: function() {
-          return [
-            function() {
-              beforesWereCalled = true;
-            }
-          ];
-        },
-        onStart: startCallback,
-        queueRunnerFactory: fakeQueueRunner
+    const fakeQueueRunner = jasmine.createSpy('fakeQueueRunner');
+    let beforesWereCalled = false;
+    const startCallback = jasmine
+      .createSpy('start-callback')
+      .and.callFake(function() {
+        expect(beforesWereCalled).toBe(false);
       });
+    const spec = new jasmineUnderTest.Spec({
+      queueableFn: { fn: function() {} },
+      beforeFns: function() {
+        return [
+          function() {
+            beforesWereCalled = true;
+          }
+        ];
+      },
+      onStart: startCallback
+    });
 
-    spec.execute();
+    spec.execute(fakeQueueRunner);
 
     fakeQueueRunner.calls.mostRecent().args[0].queueableFns[0].fn();
     expect(startCallback).toHaveBeenCalled();
   });
 
   it('provides all before fns and after fns to be run', function() {
-    var fakeQueueRunner = jasmine.createSpy('fakeQueueRunner'),
+    const fakeQueueRunner = jasmine.createSpy('fakeQueueRunner'),
       before = jasmine.createSpy('before'),
       after = jasmine.createSpy('after'),
       queueableFn = {
@@ -106,13 +103,12 @@ describe('Spec', function() {
         queueableFn: queueableFn,
         beforeAndAfterFns: function() {
           return { befores: [before], afters: [after] };
-        },
-        queueRunnerFactory: fakeQueueRunner
+        }
       });
 
-    spec.execute();
+    spec.execute(fakeQueueRunner);
 
-    var options = fakeQueueRunner.calls.mostRecent().args[0];
+    const options = fakeQueueRunner.calls.mostRecent().args[0];
     expect(options.queueableFns).toEqual([
       { fn: jasmine.any(Function) },
       before,
@@ -126,16 +122,15 @@ describe('Spec', function() {
   });
 
   it("tells the queue runner that it's a leaf node", function() {
-    var fakeQueueRunner = jasmine.createSpy('fakeQueueRunner'),
+    const fakeQueueRunner = jasmine.createSpy('fakeQueueRunner'),
       spec = new jasmineUnderTest.Spec({
         queueableFn: { fn: function() {} },
         beforeAndAfterFns: function() {
           return { befores: [], afters: [] };
-        },
-        queueRunnerFactory: fakeQueueRunner
+        }
       });
 
-    spec.execute();
+    spec.execute(fakeQueueRunner);
 
     expect(fakeQueueRunner).toHaveBeenCalledWith(
       jasmine.objectContaining({
@@ -145,32 +140,29 @@ describe('Spec', function() {
   });
 
   it('is marked pending if created without a function body', function() {
-    var fakeQueueRunner = jasmine.createSpy('fakeQueueRunner'),
-      startCallback = jasmine.createSpy('startCallback'),
+    const startCallback = jasmine.createSpy('startCallback'),
       resultCallback = jasmine.createSpy('resultCallback'),
       spec = new jasmineUnderTest.Spec({
         onStart: startCallback,
         queueableFn: { fn: null },
-        resultCallback: resultCallback,
-        queueRunnerFactory: fakeQueueRunner
+        resultCallback: resultCallback
       });
 
     expect(spec.status()).toBe('pending');
   });
 
   it('can be excluded at execution time by a parent', function() {
-    var fakeQueueRunner = jasmine.createSpy('fakeQueueRunner'),
+    const fakeQueueRunner = jasmine.createSpy('fakeQueueRunner'),
       startCallback = jasmine.createSpy('startCallback'),
       specBody = jasmine.createSpy('specBody'),
       resultCallback = jasmine.createSpy('resultCallback'),
       spec = new jasmineUnderTest.Spec({
         onStart: startCallback,
         queueableFn: { fn: specBody },
-        resultCallback: resultCallback,
-        queueRunnerFactory: fakeQueueRunner
+        resultCallback: resultCallback
       });
 
-    spec.execute('cally-back', true);
+    spec.execute(fakeQueueRunner, 'cally-back', true);
 
     expect(fakeQueueRunner).toHaveBeenCalledWith(
       jasmine.objectContaining({
@@ -186,7 +178,7 @@ describe('Spec', function() {
     );
     expect(specBody).not.toHaveBeenCalled();
 
-    var args = fakeQueueRunner.calls.mostRecent().args[0];
+    const args = fakeQueueRunner.calls.mostRecent().args[0];
     args.queueableFns[0].fn();
     expect(startCallback).toHaveBeenCalled();
     args.queueableFns[args.queueableFns.length - 1].fn();
@@ -196,7 +188,7 @@ describe('Spec', function() {
   });
 
   it('can be marked pending, but still calls callbacks when executed', function() {
-    var fakeQueueRunner = jasmine.createSpy('fakeQueueRunner'),
+    const fakeQueueRunner = jasmine.createSpy('fakeQueueRunner'),
       startCallback = jasmine.createSpy('startCallback'),
       resultCallback = jasmine.createSpy('resultCallback'),
       spec = new jasmineUnderTest.Spec({
@@ -206,7 +198,6 @@ describe('Spec', function() {
         getSpecName: function() {
           return 'a suite with a spec';
         },
-        queueRunnerFactory: fakeQueueRunner,
         queueableFn: { fn: null }
       });
 
@@ -214,11 +205,11 @@ describe('Spec', function() {
 
     expect(spec.status()).toBe('pending');
 
-    spec.execute();
+    spec.execute(fakeQueueRunner);
 
     expect(fakeQueueRunner).toHaveBeenCalled();
 
-    var args = fakeQueueRunner.calls.mostRecent().args[0];
+    const args = fakeQueueRunner.calls.mostRecent().args[0];
     args.queueableFns[0].fn();
     expect(startCallback).toHaveBeenCalled();
     args.queueableFns[1].fn('things');
@@ -241,38 +232,35 @@ describe('Spec', function() {
   });
 
   it('should call the done callback on execution complete', function() {
-    var done = jasmine.createSpy('done callback'),
+    const done = jasmine.createSpy('done callback'),
       spec = new jasmineUnderTest.Spec({
         queueableFn: { fn: function() {} },
         catchExceptions: function() {
           return false;
         },
-        resultCallback: function() {},
-        queueRunnerFactory: function(attrs) {
-          attrs.onComplete();
-        }
+        resultCallback: function() {}
       });
 
-    spec.execute(done);
+    spec.execute(attrs => attrs.onComplete(), done);
 
     expect(done).toHaveBeenCalled();
   });
 
   it('should call the done callback with an error if the spec is failed', function() {
-    var done = jasmine.createSpy('done callback'),
+    const done = jasmine.createSpy('done callback'),
       spec = new jasmineUnderTest.Spec({
         queueableFn: { fn: function() {} },
         catchExceptions: function() {
           return false;
         },
-        resultCallback: function() {},
-        queueRunnerFactory: function(attrs) {
-          spec.result.status = 'failed';
-          attrs.onComplete();
-        }
+        resultCallback: function() {}
       });
 
-    spec.execute(done);
+    function queueRunnerFactory(attrs) {
+      spec.result.status = 'failed';
+      attrs.onComplete();
+    }
+    spec.execute(queueRunnerFactory, done);
 
     expect(done).toHaveBeenCalledWith(
       jasmine.any(jasmineUnderTest.StopExecutionError)
@@ -280,150 +268,224 @@ describe('Spec', function() {
   });
 
   it('should report the duration of the test', function() {
-    var timer = jasmine.createSpyObj('timer', { start: null, elapsed: 77000 }),
-      spec = new jasmineUnderTest.Spec({
-        queueableFn: { fn: jasmine.createSpy('spec body') },
-        catchExceptions: function() {
-          return false;
-        },
-        resultCallback: function(result) {
-          duration = result.duration;
-        },
-        queueRunnerFactory: function(config) {
-          config.queueableFns.forEach(function(qf) {
-            qf.fn();
-          });
-          config.onComplete();
-        },
-        timer: timer
-      }),
-      duration = undefined;
+    const timer = jasmine.createSpyObj('timer', {
+      start: null,
+      elapsed: 77000
+    });
+    let duration = undefined;
+    const spec = new jasmineUnderTest.Spec({
+      queueableFn: { fn: jasmine.createSpy('spec body') },
+      catchExceptions: function() {
+        return false;
+      },
+      resultCallback: function(result) {
+        duration = result.duration;
+      },
+      timer: timer
+    });
 
-    spec.execute(function() {});
+    function queueRunnerFactory(config) {
+      config.queueableFns.forEach(function(qf) {
+        qf.fn();
+      });
+      config.onComplete();
+    }
+
+    spec.execute(queueRunnerFactory, function() {});
     expect(duration).toBe(77000);
   });
 
   it('should report properties set during the test', function() {
-    var done = jasmine.createSpy('done callback'),
+    const done = jasmine.createSpy('done callback'),
       spec = new jasmineUnderTest.Spec({
         queueableFn: { fn: jasmine.createSpy('spec body') },
         catchExceptions: function() {
           return false;
         },
-        resultCallback: function() {},
-        queueRunnerFactory: function(attrs) {
-          attrs.onComplete();
-        }
+        resultCallback: function() {}
       });
     spec.setSpecProperty('a', 4);
-    spec.execute(done);
+    spec.execute(attrs => attrs.onComplete(), done);
     expect(spec.result.properties).toEqual({ a: 4 });
   });
 
   it('#status returns passing by default', function() {
-    var spec = new jasmineUnderTest.Spec({
+    const spec = new jasmineUnderTest.Spec({
       queueableFn: { fn: jasmine.createSpy('spec body') }
     });
     expect(spec.status()).toBe('passed');
   });
 
   it('#status returns passed if all expectations in the spec have passed', function() {
-    var spec = new jasmineUnderTest.Spec({
+    const spec = new jasmineUnderTest.Spec({
       queueableFn: { fn: jasmine.createSpy('spec body') }
     });
-    spec.addExpectationResult(true);
+    spec.addExpectationResult(true, {});
     expect(spec.status()).toBe('passed');
   });
 
   it('#status returns failed if any expectations in the spec have failed', function() {
-    var spec = new jasmineUnderTest.Spec({
+    const spec = new jasmineUnderTest.Spec({
       queueableFn: { fn: jasmine.createSpy('spec body') }
     });
-    spec.addExpectationResult(true);
-    spec.addExpectationResult(false);
+    spec.addExpectationResult(true, {});
+    spec.addExpectationResult(false, {});
     expect(spec.status()).toBe('failed');
   });
 
   it('keeps track of passed and failed expectations', function() {
-    var fakeQueueRunner = jasmine.createSpy('queueRunner'),
+    const fakeQueueRunner = jasmine.createSpy('queueRunner'),
       resultCallback = jasmine.createSpy('resultCallback'),
       spec = new jasmineUnderTest.Spec({
         queueableFn: { fn: jasmine.createSpy('spec body') },
-        expectationResultFactory: function(data) {
-          return data;
-        },
-        queueRunnerFactory: fakeQueueRunner,
         resultCallback: resultCallback
       });
-    spec.addExpectationResult(true, 'expectation1');
-    spec.addExpectationResult(false, 'expectation2');
+    spec.addExpectationResult(true, { message: 'expectation1' });
+    spec.addExpectationResult(false, { message: 'expectation2' });
 
-    spec.execute();
+    spec.execute(fakeQueueRunner);
 
     const fns = fakeQueueRunner.calls.mostRecent().args[0].queueableFns;
     fns[fns.length - 1].fn();
 
     expect(resultCallback.calls.first().args[0].passedExpectations).toEqual([
-      'expectation1'
+      jasmine.objectContaining({ message: 'expectation1' })
     ]);
     expect(resultCallback.calls.first().args[0].failedExpectations).toEqual([
-      'expectation2'
+      jasmine.objectContaining({ message: 'expectation2' })
     ]);
   });
 
   it("throws an ExpectationFailed error upon receiving a failed expectation when 'throwOnExpectationFailure' is set", function() {
-    var fakeQueueRunner = jasmine.createSpy('queueRunner'),
+    const fakeQueueRunner = jasmine.createSpy('queueRunner'),
       resultCallback = jasmine.createSpy('resultCallback'),
       spec = new jasmineUnderTest.Spec({
         queueableFn: { fn: function() {} },
-        expectationResultFactory: function(data) {
-          return data;
-        },
-        queueRunnerFactory: fakeQueueRunner,
         resultCallback: resultCallback,
         throwOnExpectationFailure: true
       });
 
-    spec.addExpectationResult(true, 'passed');
+    spec.addExpectationResult(true, { message: 'passed' });
     expect(function() {
-      spec.addExpectationResult(false, 'failed');
+      spec.addExpectationResult(false, { message: 'failed' });
     }).toThrowError(jasmineUnderTest.errors.ExpectationFailed);
 
-    spec.execute();
+    spec.execute(fakeQueueRunner);
 
     const fns = fakeQueueRunner.calls.mostRecent().args[0].queueableFns;
     fns[fns.length - 1].fn();
     expect(resultCallback.calls.first().args[0].passedExpectations).toEqual([
-      'passed'
+      jasmine.objectContaining({ message: 'passed' })
     ]);
     expect(resultCallback.calls.first().args[0].failedExpectations).toEqual([
-      'failed'
+      jasmine.objectContaining({ message: 'failed' })
     ]);
   });
 
+  it('forwards late expectation failures to onLateError', function() {
+    const onLateError = jasmine.createSpy('onLateError');
+    const spec = new jasmineUnderTest.Spec({
+      onLateError,
+      queueableFn: { fn: function() {} }
+    });
+    const data = {
+      matcherName: '',
+      passed: false,
+      expected: '',
+      actual: '',
+      error: new Error('nope')
+    };
+
+    spec.reportedDone = true;
+    spec.addExpectationResult(false, data, true);
+
+    expect(onLateError).toHaveBeenCalledWith(
+      jasmine.objectContaining({
+        message: jasmine.stringMatching(/^Error: nope/)
+      })
+    );
+    expect(spec.result.failedExpectations).toEqual([]);
+  });
+
+  it('does not forward non-late expectation failures to onLateError', function() {
+    const onLateError = jasmine.createSpy('onLateError');
+    const spec = new jasmineUnderTest.Spec({
+      onLateError,
+      queueableFn: { fn: function() {} }
+    });
+    const data = {
+      matcherName: '',
+      passed: false,
+      expected: '',
+      actual: '',
+      error: new Error('nope')
+    };
+
+    spec.addExpectationResult(false, data, true);
+
+    expect(onLateError).not.toHaveBeenCalled();
+  });
+
+  it('forwards late handleException calls to onLateError', function() {
+    const onLateError = jasmine.createSpy('onLateError');
+    const spec = new jasmineUnderTest.Spec({
+      onLateError,
+      queueableFn: { fn: function() {} }
+    });
+
+    spec.reportedDone = true;
+    spec.handleException(new Error('oops'));
+
+    expect(onLateError).toHaveBeenCalledWith(
+      jasmine.objectContaining({
+        message: jasmine.stringMatching(/^Error: oops/)
+      })
+    );
+    expect(spec.result.failedExpectations).toEqual([]);
+  });
+
+  it('does not forward non-late handleException calls to onLateError', function() {
+    const onLateError = jasmine.createSpy('onLateError');
+    const spec = new jasmineUnderTest.Spec({
+      onLateError,
+      queueableFn: { fn: function() {} }
+    });
+    const error = new Error('oops');
+
+    spec.handleException(error);
+
+    expect(onLateError).not.toHaveBeenCalled();
+    expect(spec.result.failedExpectations.length).toEqual(1);
+  });
+
+  it('clears the reportedDone flag when reset', function() {
+    const spec = new jasmineUnderTest.Spec({
+      queueableFn: { fn: function() {} }
+    });
+    spec.reportedDone = true;
+
+    spec.reset();
+
+    expect(spec.reportedDone).toBeFalse();
+  });
+
   it('does not throw an ExpectationFailed error when handling an error', function() {
-    var resultCallback = jasmine.createSpy('resultCallback'),
+    const resultCallback = jasmine.createSpy('resultCallback'),
       spec = new jasmineUnderTest.Spec({
         queueableFn: { fn: function() {} },
-        expectationResultFactory: function(data) {
-          return data;
-        },
-        queueRunnerFactory: function(attrs) {
-          attrs.onComplete();
-        },
         resultCallback: resultCallback,
         throwOnExpectationFailure: true
       });
 
-    spec.onException('failing exception');
+    spec.handleException('failing exception');
   });
 
   it('can return its full name', function() {
-    var specNameSpy = jasmine
+    const specNameSpy = jasmine
       .createSpy('specNameSpy')
       .and.returnValue('expected val');
 
-    var spec = new jasmineUnderTest.Spec({
+    const spec = new jasmineUnderTest.Spec({
       getSpecName: specNameSpy,
       queueableFn: { fn: null }
     });
@@ -434,7 +496,7 @@ describe('Spec', function() {
 
   describe('when a spec is marked pending during execution', function() {
     it('should mark the spec as pending', function() {
-      var fakeQueueRunner = function(opts) {
+      const fakeQueueRunner = function(opts) {
           opts.onException(
             new Error(jasmineUnderTest.Spec.pendingSpecExceptionMessage)
           );
@@ -442,18 +504,17 @@ describe('Spec', function() {
         spec = new jasmineUnderTest.Spec({
           description: 'my test',
           id: 'some-id',
-          queueableFn: { fn: function() {} },
-          queueRunnerFactory: fakeQueueRunner
+          queueableFn: { fn: function() {} }
         });
 
-      spec.execute();
+      spec.execute(fakeQueueRunner);
 
       expect(spec.status()).toEqual('pending');
       expect(spec.result.pendingReason).toEqual('');
     });
 
     it('should set the pendingReason', function() {
-      var fakeQueueRunner = function(opts) {
+      const fakeQueueRunner = function(opts) {
           opts.onException(
             new Error(
               jasmineUnderTest.Spec.pendingSpecExceptionMessage +
@@ -464,11 +525,10 @@ describe('Spec', function() {
         spec = new jasmineUnderTest.Spec({
           description: 'my test',
           id: 'some-id',
-          queueableFn: { fn: function() {} },
-          queueRunnerFactory: fakeQueueRunner
+          queueableFn: { fn: function() {} }
         });
 
-      spec.execute();
+      spec.execute(fakeQueueRunner);
 
       expect(spec.status()).toEqual('pending');
       expect(spec.result.pendingReason).toEqual('custom message');
@@ -476,66 +536,58 @@ describe('Spec', function() {
   });
 
   it('should log a failure when handling an exception', function() {
-    var fakeQueueRunner = jasmine.createSpy('queueRunner'),
+    const fakeQueueRunner = jasmine.createSpy('queueRunner'),
       resultCallback = jasmine.createSpy('resultCallback'),
       spec = new jasmineUnderTest.Spec({
         queueableFn: { fn: function() {} },
-        expectationResultFactory: function(data) {
-          return data;
-        },
-        queueRunnerFactory: fakeQueueRunner,
         resultCallback: resultCallback
       });
 
-    spec.onException('foo');
-    spec.execute();
+    spec.handleException('foo');
+    spec.execute(fakeQueueRunner);
 
-    var args = fakeQueueRunner.calls.mostRecent().args[0];
+    const args = fakeQueueRunner.calls.mostRecent().args[0];
     args.queueableFns[args.queueableFns.length - 1].fn();
     expect(resultCallback.calls.first().args[0].failedExpectations).toEqual([
       {
-        error: 'foo',
+        message: 'foo thrown',
         matcherName: '',
         passed: false,
         expected: '',
-        actual: ''
+        actual: '',
+        stack: null
       }
     ]);
   });
 
   it('should not log an additional failure when handling an ExpectationFailed error', function() {
-    var fakeQueueRunner = jasmine.createSpy('queueRunner'),
+    const fakeQueueRunner = jasmine.createSpy('queueRunner'),
       resultCallback = jasmine.createSpy('resultCallback'),
       spec = new jasmineUnderTest.Spec({
         queueableFn: { fn: function() {} },
-        expectationResultFactory: function(data) {
-          return data;
-        },
-        queueRunnerFactory: fakeQueueRunner,
         resultCallback: resultCallback
       });
 
-    spec.onException(new jasmineUnderTest.errors.ExpectationFailed());
-    spec.execute();
+    spec.handleException(new jasmineUnderTest.errors.ExpectationFailed());
+    spec.execute(fakeQueueRunner);
 
-    var args = fakeQueueRunner.calls.mostRecent().args[0];
+    const args = fakeQueueRunner.calls.mostRecent().args[0];
     args.queueableFns[args.queueableFns.length - 1].fn();
     expect(resultCallback.calls.first().args[0].failedExpectations).toEqual([]);
   });
 
   it('treats multiple done calls as late errors', function() {
-    var queueRunnerFactory = jasmine.createSpy('queueRunnerFactory'),
+    const queueRunnerFactory = jasmine.createSpy('queueRunnerFactory'),
       onLateError = jasmine.createSpy('onLateError'),
       spec = new jasmineUnderTest.Spec({
         onLateError: onLateError,
         queueableFn: { fn: function() {} },
-        queueRunnerFactory: queueRunnerFactory,
         getSpecName: function() {
           return 'a spec';
         }
       });
 
-    spec.execute();
+    spec.execute(queueRunnerFactory);
 
     expect(queueRunnerFactory).toHaveBeenCalled();
     queueRunnerFactory.calls.argsFor(0)[0].onMultipleDone();
@@ -550,18 +602,17 @@ describe('Spec', function() {
 
   describe('#trace', function() {
     it('adds the messages to the result', function() {
-      var timer = jasmine.createSpyObj('timer', ['start', 'elapsed']),
+      const timer = jasmine.createSpyObj('timer', ['start', 'elapsed']),
         spec = new jasmineUnderTest.Spec({
           queueableFn: {
             fn: function() {}
           },
-          queueRunnerFactory: function() {},
           timer: timer
         }),
         t1 = 123,
         t2 = 456;
 
-      spec.execute();
+      spec.execute(() => {});
       expect(spec.result.debugLogs).toBeNull();
       timer.elapsed.and.returnValue(t1);
       spec.debugLog('msg 1');
@@ -578,22 +629,23 @@ describe('Spec', function() {
 
     describe('When the spec passes', function() {
       it('omits the messages from the reported result', function() {
-        var resultCallback = jasmine.createSpy('resultCallback'),
+        const resultCallback = jasmine.createSpy('resultCallback'),
           spec = new jasmineUnderTest.Spec({
             queueableFn: {
               fn: function() {}
             },
-            resultCallback: resultCallback,
-            queueRunnerFactory: function(config) {
-              spec.debugLog('msg');
-              for (const fn of config.queueableFns) {
-                fn.fn();
-              }
-              config.onComplete(false);
-            }
+            resultCallback: resultCallback
           });
 
-        spec.execute(function() {});
+        function queueRunnerFactory(config) {
+          spec.debugLog('msg');
+          for (const fn of config.queueableFns) {
+            fn.fn();
+          }
+          config.onComplete(false);
+        }
+
+        spec.execute(queueRunnerFactory, function() {});
         expect(resultCallback).toHaveBeenCalledWith(
           jasmine.objectContaining({ debugLogs: null }),
           undefined
@@ -601,22 +653,23 @@ describe('Spec', function() {
       });
 
       it('removes the messages to save memory', function() {
-        var resultCallback = jasmine.createSpy('resultCallback'),
+        const resultCallback = jasmine.createSpy('resultCallback'),
           spec = new jasmineUnderTest.Spec({
             queueableFn: {
               fn: function() {}
             },
-            resultCallback: resultCallback,
-            queueRunnerFactory: function(config) {
-              spec.debugLog('msg');
-              for (const fn of config.queueableFns) {
-                fn.fn();
-              }
-              config.onComplete(false);
-            }
+            resultCallback: resultCallback
           });
 
-        spec.execute(function() {});
+        function queueRunnerFactory(config) {
+          spec.debugLog('msg');
+          for (const fn of config.queueableFns) {
+            fn.fn();
+          }
+          config.onComplete(false);
+        }
+
+        spec.execute(queueRunnerFactory, function() {});
         expect(resultCallback).toHaveBeenCalled();
         expect(spec.result.debugLogs).toBeNull();
       });
@@ -624,28 +677,29 @@ describe('Spec', function() {
 
     describe('When the spec fails', function() {
       it('includes the messages in the reported result', function() {
-        var resultCallback = jasmine.createSpy('resultCallback'),
+        const resultCallback = jasmine.createSpy('resultCallback'),
           timer = jasmine.createSpyObj('timer', ['start', 'elapsed']),
           spec = new jasmineUnderTest.Spec({
             queueableFn: {
               fn: function() {}
             },
             resultCallback: resultCallback,
-            queueRunnerFactory: function(config) {
-              spec.debugLog('msg');
-              spec.onException(new Error('nope'));
-              for (const fn of config.queueableFns) {
-                fn.fn();
-              }
-              config.onComplete(true);
-            },
             timer: timer
           }),
           timestamp = 12345;
 
         timer.elapsed.and.returnValue(timestamp);
 
-        spec.execute(function() {});
+        function queueRunnerFactory(config) {
+          spec.debugLog('msg');
+          spec.handleException(new Error('nope'));
+          for (const fn of config.queueableFns) {
+            fn.fn();
+          }
+          config.onComplete(true);
+        }
+
+        spec.execute(queueRunnerFactory, function() {});
         expect(resultCallback).toHaveBeenCalledWith(
           jasmine.objectContaining({
             debugLogs: [{ message: 'msg', timestamp: timestamp }]
