@@ -1,5 +1,5 @@
 describe('spec running', function() {
-  var env;
+  let env;
 
   beforeEach(function() {
     jasmine.getEnv().registerIntegrationMatchers();
@@ -12,7 +12,7 @@ describe('spec running', function() {
   });
 
   it('should assign spec ids sequentially', function() {
-    var it0, it1, it2, it3, it4;
+    let it0, it1, it2, it3, it4;
     env.describe('test suite', function() {
       it0 = env.it('spec 0', function() {});
       it1 = env.it('spec 1', function() {});
@@ -30,12 +30,12 @@ describe('spec running', function() {
     expect(it4.id).toEqual('spec4');
   });
 
-  it('nested suites', function(done) {
-    var foo = 0;
-    var bar = 0;
-    var baz = 0;
-    var quux = 0;
-    var nested = env.describe('suite', function() {
+  it('nested suites', async function() {
+    let foo = 0;
+    let bar = 0;
+    let baz = 0;
+    let quux = 0;
+    env.describe('suite', function() {
       env.describe('nested', function() {
         env.it('should run nested suites', function() {
           foo++;
@@ -61,17 +61,16 @@ describe('spec running', function() {
     expect(baz).toEqual(0);
     expect(quux).toEqual(0);
 
-    env.execute(null, function() {
-      expect(foo).toEqual(1);
-      expect(bar).toEqual(1);
-      expect(baz).toEqual(1);
-      expect(quux).toEqual(1);
-      done();
-    });
+    await env.execute();
+
+    expect(foo).toEqual(1);
+    expect(bar).toEqual(1);
+    expect(baz).toEqual(1);
+    expect(quux).toEqual(1);
   });
 
-  it('should permit nested describes', function(done) {
-    var actions = [];
+  it('should permit nested describes', async function() {
+    const actions = [];
 
     env.beforeEach(function() {
       actions.push('topSuite beforeEach');
@@ -127,43 +126,42 @@ describe('spec running', function() {
       });
     });
 
-    env.execute(null, function() {
-      var expected = [
-        'topSuite beforeEach',
-        'outer beforeEach',
-        'outer it 1',
-        'outer afterEach',
-        'topSuite afterEach',
+    await env.execute();
 
-        'topSuite beforeEach',
-        'outer beforeEach',
-        'inner 1 beforeEach',
-        'inner 1 it',
-        'inner 1 afterEach',
-        'outer afterEach',
-        'topSuite afterEach',
+    const expected = [
+      'topSuite beforeEach',
+      'outer beforeEach',
+      'outer it 1',
+      'outer afterEach',
+      'topSuite afterEach',
 
-        'topSuite beforeEach',
-        'outer beforeEach',
-        'outer it 2',
-        'outer afterEach',
-        'topSuite afterEach',
+      'topSuite beforeEach',
+      'outer beforeEach',
+      'inner 1 beforeEach',
+      'inner 1 it',
+      'inner 1 afterEach',
+      'outer afterEach',
+      'topSuite afterEach',
 
-        'topSuite beforeEach',
-        'outer beforeEach',
-        'inner 2 beforeEach',
-        'inner 2 it',
-        'inner 2 afterEach',
-        'outer afterEach',
-        'topSuite afterEach'
-      ];
-      expect(actions).toEqual(expected);
-      done();
-    });
+      'topSuite beforeEach',
+      'outer beforeEach',
+      'outer it 2',
+      'outer afterEach',
+      'topSuite afterEach',
+
+      'topSuite beforeEach',
+      'outer beforeEach',
+      'inner 2 beforeEach',
+      'inner 2 it',
+      'inner 2 afterEach',
+      'outer afterEach',
+      'topSuite afterEach'
+    ];
+    expect(actions).toEqual(expected);
   });
 
-  it('should run multiple befores and afters ordered so functions declared later are treated as more specific', function(done) {
-    var actions = [];
+  it('should run multiple befores and afters ordered so functions declared later are treated as more specific', async function() {
+    const actions = [];
 
     env.beforeAll(function() {
       actions.push('runner beforeAll1');
@@ -219,29 +217,28 @@ describe('spec running', function() {
       });
     });
 
-    env.execute(null, function() {
-      var expected = [
-        'runner beforeAll1',
-        'runner beforeAll2',
-        'runner beforeEach1',
-        'runner beforeEach2',
-        'beforeEach1',
-        'beforeEach2',
-        'outer it 1',
-        'afterEach2',
-        'afterEach1',
-        'runner afterEach2',
-        'runner afterEach1',
-        'runner afterAll2',
-        'runner afterAll1'
-      ];
-      expect(actions).toEqual(expected);
-      done();
-    });
+    await env.execute();
+
+    const expected = [
+      'runner beforeAll1',
+      'runner beforeAll2',
+      'runner beforeEach1',
+      'runner beforeEach2',
+      'beforeEach1',
+      'beforeEach2',
+      'outer it 1',
+      'afterEach2',
+      'afterEach1',
+      'runner afterEach2',
+      'runner afterEach1',
+      'runner afterAll2',
+      'runner afterAll1'
+    ];
+    expect(actions).toEqual(expected);
   });
 
-  it('should run beforeAlls before beforeEachs and afterAlls after afterEachs', function(done) {
-    var actions = [];
+  it('should run beforeAlls before beforeEachs and afterAlls after afterEachs', async function() {
+    const actions = [];
 
     env.beforeAll(function() {
       actions.push('runner beforeAll');
@@ -281,27 +278,26 @@ describe('spec running', function() {
       });
     });
 
-    env.execute(null, function() {
-      var expected = [
-        'runner beforeAll',
-        'inner beforeAll',
-        'runner beforeEach',
-        'inner beforeEach',
-        'it',
-        'inner afterEach',
-        'runner afterEach',
-        'inner afterAll',
-        'runner afterAll'
-      ];
-      expect(actions).toEqual(expected);
-      done();
-    });
+    await env.execute();
+
+    const expected = [
+      'runner beforeAll',
+      'inner beforeAll',
+      'runner beforeEach',
+      'inner beforeEach',
+      'it',
+      'inner afterEach',
+      'runner afterEach',
+      'inner afterAll',
+      'runner afterAll'
+    ];
+    expect(actions).toEqual(expected);
   });
 
-  it('should run beforeAlls and afterAlls in the order declared when runnablesToRun is provided', function(done) {
-    var actions = [],
-      spec,
-      spec2;
+  it('should run beforeAlls and afterAlls in the order declared when runnablesToRun is provided', async function() {
+    const actions = [];
+    let spec;
+    let spec2;
 
     env.beforeAll(function() {
       actions.push('runner beforeAll');
@@ -345,31 +341,30 @@ describe('spec running', function() {
       });
     });
 
-    env.execute([spec2.id, spec.id], function() {
-      var expected = [
-        'runner beforeAll',
-        'inner beforeAll',
-        'runner beforeEach',
-        'inner beforeEach',
-        'it2',
-        'inner afterEach',
-        'runner afterEach',
+    await env.execute([spec2.id, spec.id]);
 
-        'runner beforeEach',
-        'inner beforeEach',
-        'it',
-        'inner afterEach',
-        'runner afterEach',
-        'inner afterAll',
-        'runner afterAll'
-      ];
-      expect(actions).toEqual(expected);
-      done();
-    });
+    const expected = [
+      'runner beforeAll',
+      'inner beforeAll',
+      'runner beforeEach',
+      'inner beforeEach',
+      'it2',
+      'inner afterEach',
+      'runner afterEach',
+
+      'runner beforeEach',
+      'inner beforeEach',
+      'it',
+      'inner afterEach',
+      'runner afterEach',
+      'inner afterAll',
+      'runner afterAll'
+    ];
+    expect(actions).toEqual(expected);
   });
 
-  it('only runs *Alls once in a focused suite', function(done) {
-    var actions = [];
+  it('only runs *Alls once in a focused suite', async function() {
+    const actions = [];
 
     env.fdescribe('Suite', function() {
       env.beforeAll(function() {
@@ -383,15 +378,14 @@ describe('spec running', function() {
       });
     });
 
-    env.execute(null, function() {
-      expect(actions).toEqual(['beforeAll', 'spec', 'afterAll']);
-      done();
-    });
+    await env.execute();
+
+    expect(actions).toEqual(['beforeAll', 'spec', 'afterAll']);
   });
 
   describe('focused runnables', function() {
-    it('runs the relevant alls and eachs for each runnable', function(done) {
-      var actions = [];
+    it('runs the relevant alls and eachs for each runnable', async function() {
+      const actions = [];
       env.beforeAll(function() {
         actions.push('beforeAll');
       });
@@ -417,25 +411,24 @@ describe('spec running', function() {
         });
       });
 
-      env.execute(null, function() {
-        var expected = [
-          'beforeAll',
-          'beforeEach',
-          'spec in fdescribe',
-          'afterEach',
+      await env.execute();
 
-          'beforeEach',
-          'focused spec',
-          'afterEach',
-          'afterAll'
-        ];
-        expect(actions).toEqual(expected);
-        done();
-      });
+      const expected = [
+        'beforeAll',
+        'beforeEach',
+        'spec in fdescribe',
+        'afterEach',
+
+        'beforeEach',
+        'focused spec',
+        'afterEach',
+        'afterAll'
+      ];
+      expect(actions).toEqual(expected);
     });
 
-    it('focused specs in focused suites cause non-focused siblings to not run', function(done) {
-      var actions = [];
+    it('focused specs in focused suites cause non-focused siblings to not run', async function() {
+      const actions = [];
 
       env.fdescribe('focused suite', function() {
         env.it('unfocused spec', function() {
@@ -446,15 +439,14 @@ describe('spec running', function() {
         });
       });
 
-      env.execute(null, function() {
-        var expected = ['focused spec'];
-        expect(actions).toEqual(expected);
-        done();
-      });
+      await env.execute();
+
+      const expected = ['focused spec'];
+      expect(actions).toEqual(expected);
     });
 
-    it('focused suites in focused suites cause non-focused siblings to not run', function(done) {
-      var actions = [];
+    it('focused suites in focused suites cause non-focused siblings to not run', async function() {
+      const actions = [];
 
       env.fdescribe('focused suite', function() {
         env.it('unfocused spec', function() {
@@ -467,15 +459,14 @@ describe('spec running', function() {
         });
       });
 
-      env.execute(null, function() {
-        var expected = ['inner spec'];
-        expect(actions).toEqual(expected);
-        done();
-      });
+      await env.execute();
+
+      const expected = ['inner spec'];
+      expect(actions).toEqual(expected);
     });
 
-    it('focused runnables unfocus ancestor focused suites', function(done) {
-      var actions = [];
+    it('focused runnables unfocus ancestor focused suites', async function() {
+      const actions = [];
 
       env.fdescribe('focused suite', function() {
         env.it('unfocused spec', function() {
@@ -488,48 +479,45 @@ describe('spec running', function() {
         });
       });
 
-      env.execute(null, function() {
-        var expected = ['focused spec'];
-        expect(actions).toEqual(expected);
-        done();
-      });
+      await env.execute();
+
+      const expected = ['focused spec'];
+      expect(actions).toEqual(expected);
     });
   });
 
-  it("shouldn't run disabled suites", function(done) {
-    var specInADisabledSuite = jasmine.createSpy('specInADisabledSuite'),
-      suite = env.describe('A Suite', function() {
-        env.xdescribe('with a disabled suite', function() {
-          env.it('spec inside a disabled suite', specInADisabledSuite);
-        });
+  it("shouldn't run disabled suites", async function() {
+    const specInADisabledSuite = jasmine.createSpy('specInADisabledSuite');
+    env.describe('A Suite', function() {
+      env.xdescribe('with a disabled suite', function() {
+        env.it('spec inside a disabled suite', specInADisabledSuite);
       });
-
-    env.execute(null, function() {
-      expect(specInADisabledSuite).not.toHaveBeenCalled();
-      done();
     });
+
+    await env.execute();
+
+    expect(specInADisabledSuite).not.toHaveBeenCalled();
   });
 
-  it("shouldn't run before/after functions in disabled suites", function(done) {
-    var shouldNotRun = jasmine.createSpy('shouldNotRun'),
-      suite = env.xdescribe('A disabled Suite', function() {
-        // None of the before/after functions should run.
-        env.beforeAll(shouldNotRun);
-        env.beforeEach(shouldNotRun);
-        env.afterEach(shouldNotRun);
-        env.afterAll(shouldNotRun);
+  it("shouldn't run before/after functions in disabled suites", async function() {
+    const shouldNotRun = jasmine.createSpy('shouldNotRun');
+    env.xdescribe('A disabled Suite', function() {
+      // None of the before/after functions should run.
+      env.beforeAll(shouldNotRun);
+      env.beforeEach(shouldNotRun);
+      env.afterEach(shouldNotRun);
+      env.afterAll(shouldNotRun);
 
-        env.it('spec inside a disabled suite', shouldNotRun);
-      });
-
-    env.execute(null, function() {
-      expect(shouldNotRun).not.toHaveBeenCalled();
-      done();
+      env.it('spec inside a disabled suite', shouldNotRun);
     });
+
+    await env.execute();
+
+    expect(shouldNotRun).not.toHaveBeenCalled();
   });
 
-  it('should allow top level suites to be disabled', function(done) {
-    var specInADisabledSuite = jasmine.createSpy('specInADisabledSuite'),
+  it('should allow top level suites to be disabled', async function() {
+    const specInADisabledSuite = jasmine.createSpy('specInADisabledSuite'),
       otherSpec = jasmine.createSpy('otherSpec');
 
     env.xdescribe('A disabled suite', function() {
@@ -539,34 +527,31 @@ describe('spec running', function() {
       env.it('another spec', otherSpec);
     });
 
-    env.execute(null, function() {
-      expect(specInADisabledSuite).not.toHaveBeenCalled();
-      expect(otherSpec).toHaveBeenCalled();
-      done();
-    });
+    await env.execute();
+
+    expect(specInADisabledSuite).not.toHaveBeenCalled();
+    expect(otherSpec).toHaveBeenCalled();
   });
 
-  it('should set all pending specs to pending when a suite is run', function(done) {
-    var pendingSpec,
-      suite = env.describe('default current suite', function() {
-        pendingSpec = env.it('I am a pending spec');
-      }),
-      reporter = jasmine.createSpyObj('reporter', ['specDone']);
+  it('should set all pending specs to pending when a suite is run', async function() {
+    env.describe('default current suite', function() {
+      env.it('I am a pending spec');
+    });
+    const reporter = jasmine.createSpyObj('reporter', ['specDone']);
 
     env.addReporter(reporter);
 
-    env.execute(null, function() {
-      expect(reporter.specDone).toHaveBeenCalledWith(
-        jasmine.objectContaining({
-          status: 'pending'
-        })
-      );
-      done();
-    });
+    await env.execute();
+
+    expect(reporter.specDone).toHaveBeenCalledWith(
+      jasmine.objectContaining({
+        status: 'pending'
+      })
+    );
   });
 
-  it('should recover gracefully when there are errors in describe functions', function(done) {
-    var specs = [],
+  it('should recover gracefully when there are errors in describe functions', async function() {
+    const specs = [],
       reporter = jasmine.createSpyObj(['specDone', 'suiteDone']);
 
     reporter.specDone.and.callFake(function(result) {
@@ -600,28 +585,27 @@ describe('spec running', function() {
     });
 
     env.addReporter(reporter);
-    env.execute(null, function() {
-      expect(specs).toEqual([
-        'outer1 inner1 should thingy',
-        'outer1 inner2 should other thingy',
-        'outer2 should xxx'
-      ]);
-      expect(reporter.suiteDone).toHaveFailedExpectationsForRunnable(
-        'outer1 inner1',
-        [/inner error/]
-      );
-      expect(reporter.suiteDone).toHaveFailedExpectationsForRunnable('outer1', [
-        /outer error/
-      ]);
-      done();
-    });
+    await env.execute();
+
+    expect(specs).toEqual([
+      'outer1 inner1 should thingy',
+      'outer1 inner2 should other thingy',
+      'outer2 should xxx'
+    ]);
+    expect(reporter.suiteDone).toHaveFailedExpectationsForRunnable(
+      'outer1 inner1',
+      [/inner error/]
+    );
+    expect(reporter.suiteDone).toHaveFailedExpectationsForRunnable('outer1', [
+      /outer error/
+    ]);
   });
 
-  it('re-enters suites that have no *Alls', function(done) {
-    var actions = [],
-      spec1,
-      spec2,
-      spec3;
+  it('re-enters suites that have no *Alls', async function() {
+    const actions = [];
+    let spec1;
+    let spec2;
+    let spec3;
 
     env.describe('top', function() {
       spec1 = env.it('spec1', function() {
@@ -637,17 +621,16 @@ describe('spec running', function() {
       actions.push('spec3');
     });
 
-    env.execute([spec2.id, spec3.id, spec1.id], function() {
-      expect(actions).toEqual(['spec2', 'spec3', 'spec1']);
-      done();
-    });
+    await env.execute([spec2.id, spec3.id, spec1.id]);
+
+    expect(actions).toEqual(['spec2', 'spec3', 'spec1']);
   });
 
   it('refuses to re-enter suites with a beforeAll', function() {
-    var actions = [],
-      spec1,
-      spec2,
-      spec3;
+    const actions = [];
+    let spec1;
+    let spec2;
+    let spec3;
 
     env.describe('top', function() {
       env.beforeAll(function() {});
@@ -672,10 +655,10 @@ describe('spec running', function() {
   });
 
   it('refuses to re-enter suites with a afterAll', function() {
-    var actions = [],
-      spec1,
-      spec2,
-      spec3;
+    const actions = [];
+    let spec1;
+    let spec2;
+    let spec3;
 
     env.describe('top', function() {
       env.afterAll(function() {});
@@ -699,8 +682,8 @@ describe('spec running', function() {
     expect(actions).toEqual([]);
   });
 
-  it('should run the tests in a consistent order when a seed is supplied', function(done) {
-    var actions = [];
+  it('should run the tests in a consistent order when a seed is supplied', async function() {
+    const actions = [];
     env.configure({ random: true, seed: '123456' });
 
     env.beforeEach(function() {
@@ -757,39 +740,38 @@ describe('spec running', function() {
       });
     });
 
-    env.execute(null, function() {
-      var expected = [
-        'topSuite beforeEach',
-        'outer beforeEach',
-        'outer it 2',
-        'outer afterEach',
-        'topSuite afterEach',
+    await env.execute();
 
-        'topSuite beforeEach',
-        'outer beforeEach',
-        'inner 2 beforeEach',
-        'inner 2 it',
-        'inner 2 afterEach',
-        'outer afterEach',
-        'topSuite afterEach',
+    const expected = [
+      'topSuite beforeEach',
+      'outer beforeEach',
+      'outer it 2',
+      'outer afterEach',
+      'topSuite afterEach',
 
-        'topSuite beforeEach',
-        'outer beforeEach',
-        'inner 1 beforeEach',
-        'inner 1 it',
-        'inner 1 afterEach',
-        'outer afterEach',
-        'topSuite afterEach',
+      'topSuite beforeEach',
+      'outer beforeEach',
+      'inner 2 beforeEach',
+      'inner 2 it',
+      'inner 2 afterEach',
+      'outer afterEach',
+      'topSuite afterEach',
 
-        'topSuite beforeEach',
-        'outer beforeEach',
-        'outer it 1',
-        'outer afterEach',
-        'topSuite afterEach'
-      ];
-      expect(actions).toEqual(expected);
-      done();
-    });
+      'topSuite beforeEach',
+      'outer beforeEach',
+      'inner 1 beforeEach',
+      'inner 1 it',
+      'inner 1 afterEach',
+      'outer afterEach',
+      'topSuite afterEach',
+
+      'topSuite beforeEach',
+      'outer beforeEach',
+      'outer it 1',
+      'outer afterEach',
+      'topSuite afterEach'
+    ];
+    expect(actions).toEqual(expected);
   });
 
   function hasStandardErrorHandlingBehavior() {
@@ -886,6 +868,7 @@ describe('spec running', function() {
       const actions = [];
 
       env.describe('Something', function() {
+        // eslint-disable-next-line no-unused-vars
         env.beforeEach(function(innerDone) {
           actions.push('beforeEach');
         }, 1);
@@ -985,7 +968,7 @@ describe('spec running', function() {
     hasStandardErrorHandlingBehavior();
 
     it('skips to cleanup functions after an expectation failure', async function() {
-      var actions = [];
+      const actions = [];
 
       env.describe('Something', function() {
         env.beforeEach(function() {
@@ -1026,7 +1009,7 @@ describe('spec running', function() {
     hasStandardErrorHandlingBehavior();
 
     it('does not skip anything after an expectation failure', async function() {
-      var actions = [];
+      const actions = [];
 
       env.describe('Something', function() {
         env.beforeEach(function() {
@@ -1298,9 +1281,8 @@ describe('spec running', function() {
   });
 
   describe('when stopOnSpecFailure is on', function() {
-    it('does not run further specs when one fails', function(done) {
-      var actions = [],
-        config;
+    it('does not run further specs when one fails', async function() {
+      const actions = [];
 
       env.describe('wrapper', function() {
         env.it('fails', function() {
@@ -1318,10 +1300,9 @@ describe('spec running', function() {
       env.configure({ random: false });
       env.configure({ stopOnSpecFailure: true });
 
-      env.execute(null, function() {
-        expect(actions).toEqual(['fails']);
-        done();
-      });
+      await env.execute();
+
+      expect(actions).toEqual(['fails']);
     });
 
     it('runs afterAll functions', async function() {
@@ -1365,8 +1346,8 @@ describe('spec running', function() {
       env.configure({ autoCleanClosures: false, random: false });
     });
 
-    it('should be able to run multiple times', function(done) {
-      var actions = [];
+    it('should be able to run multiple times', async function() {
+      const actions = [];
 
       env.describe('Suite', function() {
         env.it('spec1', function() {
@@ -1379,19 +1360,17 @@ describe('spec running', function() {
         });
       });
 
-      env.execute(null, function() {
-        expect(actions).toEqual(['spec1', 'spec2']);
-        env.execute(null, function() {
-          expect(actions).toEqual(['spec1', 'spec2', 'spec1', 'spec2']);
-          done();
-        });
-      });
+      await env.execute();
+      expect(actions).toEqual(['spec1', 'spec2']);
+
+      await env.execute();
+      expect(actions).toEqual(['spec1', 'spec2', 'spec1', 'spec2']);
     });
 
-    it('should reset results between runs', function(done) {
-      var specResults = {};
-      var suiteResults = {};
-      var firstExecution = true;
+    it('should reset results between runs', async function() {
+      const specResults = {};
+      const suiteResults = {};
+      let firstExecution = true;
 
       env.addReporter({
         specDone: function(spec) {
@@ -1441,55 +1420,53 @@ describe('spec running', function() {
         });
       });
 
-      env.execute(null, function() {
-        expect(specResults).toEqual({
-          spec1: 'failed',
-          spec2: 'pending',
-          spec3: 'pending',
-          spec4: 'failed',
-          spec5: 'failed',
-          spec6: 'pending',
-          spec7: 'pending'
-        });
-        expect(suiteResults).toEqual({
-          suite0: 'passed',
-          suite1: 'passed',
-          suite2: 'passed',
-          suite3: 'passed',
-          suite4: 'pending',
-          suite5: 'passed'
-        });
-        env.execute(null, function() {
-          expect(specResults).toEqual({
-            spec1: 'passed',
-            spec2: 'passed',
-            spec3: 'pending',
-            spec4: 'passed',
-            spec5: 'failed',
-            spec6: 'pending',
-            spec7: 'pending'
-          });
-          expect(suiteResults).toEqual({
-            suite0: 'passed',
-            suite1: 'passed',
-            suite2: 'passed',
-            suite3: 'passed',
-            suite4: 'pending',
-            suite5: 'passed'
-          });
-          done();
-        });
+      await env.execute();
+      expect(specResults).toEqual({
+        spec1: 'failed',
+        spec2: 'pending',
+        spec3: 'pending',
+        spec4: 'failed',
+        spec5: 'failed',
+        spec6: 'pending',
+        spec7: 'pending'
+      });
+      expect(suiteResults).toEqual({
+        suite0: 'passed',
+        suite1: 'passed',
+        suite2: 'passed',
+        suite3: 'passed',
+        suite4: 'pending',
+        suite5: 'passed'
+      });
+
+      await env.execute();
+      expect(specResults).toEqual({
+        spec1: 'passed',
+        spec2: 'passed',
+        spec3: 'pending',
+        spec4: 'passed',
+        spec5: 'failed',
+        spec6: 'pending',
+        spec7: 'pending'
+      });
+      expect(suiteResults).toEqual({
+        suite0: 'passed',
+        suite1: 'passed',
+        suite2: 'passed',
+        suite3: 'passed',
+        suite4: 'pending',
+        suite5: 'passed'
       });
     });
 
-    it('should execute before and after hooks per run', function(done) {
-      var timeline = [];
-      var timelineFn = function(hookName) {
+    it('should execute before and after hooks per run', async function() {
+      let timeline = [];
+      const timelineFn = function(hookName) {
         return function() {
           timeline.push(hookName);
         };
       };
-      var expectedTimeLine = [
+      const expectedTimeLine = [
         'beforeAll',
         'beforeEach',
         'spec1',
@@ -1508,19 +1485,17 @@ describe('spec running', function() {
         env.it('spec1', timelineFn('spec1'));
         env.it('spec2', timelineFn('spec2'));
       });
-      env.execute(null, function() {
-        expect(timeline).toEqual(expectedTimeLine);
-        timeline = [];
-        env.execute(null, function() {
-          expect(timeline).toEqual(expectedTimeLine);
-          done();
-        });
-      });
+      await env.execute();
+      expect(timeline).toEqual(expectedTimeLine);
+
+      timeline = [];
+      await env.execute();
+      expect(timeline).toEqual(expectedTimeLine);
     });
 
-    it('should be able to filter out different tests in subsequent runs', function(done) {
-      var specResults = {};
-      var focussedSpec = 'spec1';
+    it('should be able to filter out different tests in subsequent runs', async function() {
+      const specResults = {};
+      let focussedSpec = 'spec1';
 
       env.configure({
         specFilter: function(spec) {
@@ -1540,29 +1515,27 @@ describe('spec running', function() {
         env.it('spec3', function() {});
       });
 
-      env.execute(null, function() {
-        expect(specResults).toEqual({
-          spec1: 'passed',
-          spec2: 'excluded',
-          spec3: 'excluded'
-        });
-        focussedSpec = 'spec2';
-        env.execute(null, function() {
-          expect(specResults).toEqual({
-            spec1: 'excluded',
-            spec2: 'passed',
-            spec3: 'excluded'
-          });
-          focussedSpec = 'spec3';
-          env.execute(null, function() {
-            expect(specResults).toEqual({
-              spec1: 'excluded',
-              spec2: 'excluded',
-              spec3: 'passed'
-            });
-            done();
-          });
-        });
+      await env.execute();
+      expect(specResults).toEqual({
+        spec1: 'passed',
+        spec2: 'excluded',
+        spec3: 'excluded'
+      });
+
+      focussedSpec = 'spec2';
+      await env.execute();
+      expect(specResults).toEqual({
+        spec1: 'excluded',
+        spec2: 'passed',
+        spec3: 'excluded'
+      });
+
+      focussedSpec = 'spec3';
+      await env.execute();
+      expect(specResults).toEqual({
+        spec1: 'excluded',
+        spec2: 'excluded',
+        spec3: 'passed'
       });
     });
   });
