@@ -1,6 +1,6 @@
 describe('NullDiffBuilder', function() {
   it('responds to withPath() by calling the passed function', function() {
-    var spy = jasmine.createSpy('callback');
+    const spy = jasmine.createSpy('callback');
     jasmineUnderTest.NullDiffBuilder().withPath('does not matter', spy);
     expect(spy).toHaveBeenCalled();
   });
