@@ -1,6 +1,6 @@
 describe('toBeResolved', function() {
   it('passes if the actual is resolved', function() {
-    var matchersUtil = new jasmineUnderTest.MatchersUtil(),
+    const matchersUtil = new jasmineUnderTest.MatchersUtil(),
       matcher = jasmineUnderTest.asyncMatchers.toBeResolved(matchersUtil),
       actual = Promise.resolve();
 
@@ -10,7 +10,7 @@ describe('toBeResolved', function() {
   });
 
   it('fails if the actual is rejected', function() {
-    var matchersUtil = new jasmineUnderTest.MatchersUtil({
+    const matchersUtil = new jasmineUnderTest.MatchersUtil({
         pp: jasmineUnderTest.makePrettyPrinter([])
       }),
       matcher = jasmineUnderTest.asyncMatchers.toBeResolved(matchersUtil),
@@ -27,7 +27,7 @@ describe('toBeResolved', function() {
   });
 
   it('fails if actual is not a promise', function() {
-    var matchersUtil = new jasmineUnderTest.MatchersUtil(),
+    const matchersUtil = new jasmineUnderTest.MatchersUtil(),
       matcher = jasmineUnderTest.asyncMatchers.toBeResolved(matchersUtil),
       actual = 'not a promise';
 
