@@ -1,6 +1,6 @@
 describe('nothing', function() {
   it('should pass', function() {
-    var matcher = jasmineUnderTest.matchers.nothing(),
+    const matcher = jasmineUnderTest.matchers.nothing(),
       result = matcher.compare();
 
     expect(result.pass).toBe(true);
