@@ -1,7 +1,7 @@
 describe('toBeLessThanOrEqual', function() {
   it('passes when actual <= expected', function() {
-    var matcher = jasmineUnderTest.matchers.toBeLessThanOrEqual(),
-      result;
+    const matcher = jasmineUnderTest.matchers.toBeLessThanOrEqual();
+    let result;
 
     result = matcher.compare(1, 2);
     expect(result.pass).toBe(true);
@@ -17,8 +17,8 @@ describe('toBeLessThanOrEqual', function() {
   });
 
   it('fails when actual < expected', function() {
-    var matcher = jasmineUnderTest.matchers.toBeLessThanOrEqual(),
-      result;
+    const matcher = jasmineUnderTest.matchers.toBeLessThanOrEqual();
+    let result;
 
     result = matcher.compare(2, 1);
     expect(result.pass).toBe(false);
