@@ -1,11 +1,11 @@
 (function(env) {
   function browserVersion(matchFn) {
-    var userAgent = jasmine.getGlobal().navigator.userAgent;
+    const userAgent = jasmine.getGlobal().navigator.userAgent;
     if (!userAgent) {
       return void 0;
     }
 
-    var match = matchFn(userAgent);
+    const match = matchFn(userAgent);
 
     return match ? parseFloat(match[1]) : void 0;
   }
