@@ -1,19 +1,19 @@
 (function(env) {
   function domHelpers() {
-    var doc;
+    let doc;
 
     if (typeof document !== 'undefined') {
       doc = document;
     } else {
-      var JSDOM = require('jsdom').JSDOM;
-      var dom = new JSDOM();
+      const JSDOM = require('jsdom').JSDOM;
+      const dom = new JSDOM();
       doc = dom.window.document;
     }
 
     return {
       document: doc,
       createElementWithClassName: function(className) {
-        var el = this.document.createElement('div');
+        const el = this.document.createElement('div');
         el.className = className;
         return el;
       }
