@@ -3,7 +3,7 @@ const path = require('path'),
   jasmineBrowser = require('jasmine-browser-runner'),
   jasmineCore = require('../../lib/jasmine-core');
 
-var config = require(path.resolve('spec/support/jasmine-browser.js'));
+const config = require(path.resolve('spec/support/jasmine-browser.js'));
 config.clearReporters = true;
 config.jasmineCore = jasmineCore;
 
