@@ -41,7 +41,3 @@ module.exports = {
     }
   }
 };
-
-if (process.env.SKIP_JASMINE_BROWSER_FLAKES === 'true') {
-  module.exports.helpers.push('helpers/disableBrowserFlakes.js');
-}
